pub fn setup_socket(
shutdown_tx: &Sender<()>,
event_tx: &DaemonEventSender,
) -> Result<(&'static Path, JoinHandle<()>)>Expand description
Bind the Unix domain socket and spawn the accept loop.
pub fn setup_socket(
shutdown_tx: &Sender<()>,
event_tx: &DaemonEventSender,
) -> Result<(&'static Path, JoinHandle<()>)>Bind the Unix domain socket and spawn the accept loop.