pub struct DaemonConfig {
pub models: BTreeMap<CompactString, ProviderConfig>,
pub channels: BTreeMap<CompactString, ChannelConfig>,
pub mcp_servers: BTreeMap<CompactString, McpServerConfig>,
pub agents: AgentConfig,
}Expand description
Top-level daemon configuration.
Fields
models: BTreeMap<CompactString, ProviderConfig>LLM provider configurations keyed by a user-defined name.
If a provider’s model field is empty, it is filled from the key.
channels: BTreeMap<CompactString, ChannelConfig>Channel configurations keyed by a user-defined name.
If a channel’s platform field is empty, it is filled from the key.
mcp_servers: BTreeMap<CompactString, McpServerConfig>MCP server configurations.
agents: AgentConfigAgent configurations.
Implementations